Glossary — Products.ZMySQLDA 4.0b2.dev0 documentation

# Glossary

Interface
  An attribute of a model object that determines its type. It is an instance of a `zope.interface` Interface class. See the online documentation for more information.
Setuptools
  Setuptools builds on Python’s `distutils` to provide easier building, distribution, and installation of packages.
Virtualenv
  An isolated Python environment. Allows you to control which packages are used on a particular project by cloning your main Python. virtualenv was created by Ian Bicking.
ZCML
  XML-based configuration language used by Zope.
ZMI
  Zope offers the ZMI (Zope Managment Interface) for managing your Zope site through a browser. You can get to it by going to the path `/manage` in your Zope site and logging in with credentials for a user with role `Manager`.
Zope
  The Z Object Publishing Framework. The granddaddy of Python web frameworks.
ZODB
  The ZODB is the object database included in Zope.